:mod:`ordec.core.schema` --- Common schema for IC design data
=============================================================

This common schema ensures that different modules of ORDeC speak the same language and can interact seamlessly.

.. automodule:: ordec.core.schema

General stuff
-------------

.. autoclass:: PolyVec2R
   :members: 
   :undoc-members:

Symbols
-------

.. autoclass:: Symbol
   :members: 
   :undoc-members:
   :exclude-members: 

.. autoclass:: Pin
   :members: 
   :undoc-members:

.. autoclass:: PinType
   :members: 
   :undoc-members:

.. autoclass:: SymbolArc
   :members: 
   :undoc-members:

Schematics
----------

.. autoclass:: Schematic
   :members: 
   :undoc-members:

.. autoclass:: Net
   :members: 
   :undoc-members:

.. autoclass:: SchemPort
   :members: 
   :undoc-members:

.. autoclass:: SchemWire
   :members: 
   :undoc-members:

.. autoclass:: SchemInstance
   :members: 
   :undoc-members:

.. autoclass:: SchemInstanceConn
   :members: 
   :undoc-members:

.. autoclass:: SchemTapPoint
   :members: 
   :undoc-members:

.. autoclass:: SchemConnPoint
   :members: 
   :undoc-members:

Simulation hierarchy
--------------------

.. autoclass:: SimHierarchy
   :members: 
   :undoc-members:

.. autoclass:: SimNet
   :members: 
   :undoc-members:

.. autoclass:: SimInstance
   :members: 
   :undoc-members:

Technology definitions
----------------------

.. autoclass:: GdsLayer
   :members: 
   :undoc-members:

.. autoclass:: RGBColor
   :members: 
   :undoc-members:

.. autoclass:: LayerStack
   :members: 
   :undoc-members:

.. autoclass:: Layer
   :members: 
   :undoc-members:

Layout
------

.. autoclass:: Layout
   :members: 
   :undoc-members:

.. autoclass:: LayoutLabel
   :members: 
   :undoc-members:

.. autoclass:: LayoutPoly
   :members: 
   :undoc-members:

.. autoclass:: LayoutPath
   :members: 
   :undoc-members:

.. autoclass:: LayoutRectPoly
   :members: 
   :undoc-members:

.. autoclass:: LayoutRectPath
   :members: 
   :undoc-members:

.. autoclass:: LayoutRect
   :members: 
   :undoc-members:

.. autoclass:: LayoutInstance
   :members: 
   :undoc-members:

.. autoclass:: LayoutInstanceArray
   :members: 
   :undoc-members:

.. autoclass:: LayoutPin
   :members: 
   :undoc-members:

.. autoclass:: PathEndType
   :members: 
   :undoc-members:

.. autoclass:: RectDirection
   :members: 
   :undoc-members:
